@@ -26,7 +26,6 @@ import (
 	monitoring "github.com/coreos/prometheus-operator/pkg/client/versioned"
 	"github.com/coreos/prometheus-operator/pkg/k8sutil"
 	prometheusoperator "github.com/coreos/prometheus-operator/pkg/prometheus"
-	"github.com/golang/glog"
 	configv1 "github.com/openshift/api/config/v1"
 	routev1 "github.com/openshift/api/route/v1"
 	secv1 "github.com/openshift/api/security/v1"
@@ -38,7 +37,7 @@ import (
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/api/extensions/v1beta1"
 	v1betaextensions "k8s.io/api/extensions/v1beta1"
-	rbacv1beta1 "k8s.io/api/rbac/v1beta1"
+	rbacv1 "k8s.io/api/rbac/v1"
 	extensionsobj "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
 	apiextensionsclient "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -48,6 +47,7 @@ import (
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
+	"k8s.io/klog"
 	apiregistrationv1beta1 "k8s.io/kube-aggregator/pkg/apis/apiregistration/v1beta1"
 	aggregatorclient "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset"
 )
@@ -326,6 +326,25 @@ func (c *Client) DeleteConfigMap(cm *v1.ConfigMap) error {
 	return err
 }
 
+func (c *Client) DeleteHashedConfigMap(newHash, prefix string) error {
+	ls := "monitoring.openshift.io/name=" + prefix + ",monitoring.openshift.io/hash!=" + newHash
+	configMaps, err := c.KubernetesInterface().CoreV1().ConfigMaps(c.namespace).List(metav1.ListOptions{
+		LabelSelector: ls,
+	})
+	if err != nil {
+		return errors.Wrapf(err, "error listing configmaps with label selector %s", ls)
+	}
+
+	for i := range configMaps.Items {
+		err := c.KubernetesInterface().CoreV1().ConfigMaps(c.namespace).Delete(configMaps.Items[i].Name, &metav1.DeleteOptions{})
+		if err != nil {
+			return errors.Wrapf(err, "error deleting configmap: %s", configMaps.Items[i].Name)
+		}
+	}
+
+	return nil
+}
+
 func (c *Client) DeleteDeployment(d *appsv1.Deployment) error {
 	p := metav1.DeletePropagationForeground
 	err := c.kclient.AppsV1beta2().Deployments(d.GetNamespace()).Delete(d.GetName(), &metav1.DeleteOptions{PropagationPolicy: &p})
@@ -346,13 +365,13 @@ func (c *Client) DeletePrometheus(p *monv1.Prometheus) error {
 
 	var lastErr error
 	if err := wait.Poll(time.Second*10, time.Minute*10, func() (bool, error) {
-		pods, err := c.KubernetesInterface().Core().Pods(p.GetNamespace()).List(prometheusoperator.ListOptions(p.GetName()))
+		pods, err := c.KubernetesInterface().CoreV1().Pods(p.GetNamespace()).List(prometheusoperator.ListOptions(p.GetName()))
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving pods during polling failed")
 		}
 
-		glog.V(6).Infof("waiting for %d Pods to be deleted", len(pods.Items))
-		glog.V(6).Infof("done waiting? %t", len(pods.Items) == 0)
+		klog.V(6).Infof("waiting for %d Pods to be deleted", len(pods.Items))
+		klog.V(6).Infof("done waiting? %t", len(pods.Items) == 0)
 
 		lastErr = fmt.Errorf("waiting for %d Pods to be deleted", len(pods.Items))
 		return len(pods.Items) == 0, nil
@@ -377,9 +396,13 @@ func (c *Client) DeleteDaemonSet(d *v1beta1.DaemonSet) error {
 }
 
 func (c *Client) DeleteServiceMonitor(sm *monv1.ServiceMonitor) error {
-	sclient := c.mclient.MonitoringV1().ServiceMonitors(sm.Namespace)
+	return c.DeleteServiceMonitorByNamespaceAndName(sm.Namespace, sm.GetName())
+}
 
-	err := sclient.Delete(sm.GetName(), nil)
+func (c *Client) DeleteServiceMonitorByNamespaceAndName(namespace, name string) error {
+	sclient := c.mclient.MonitoringV1().ServiceMonitors(namespace)
+
+	err := sclient.Delete(name, nil)
 	// if the object does not exist then everything is good here
 	if err != nil && !apierrors.IsNotFound(err) {
 		return errors.Wrap(err, "deleting ServiceMonitor object failed")
@@ -397,8 +420,8 @@ func (c *Client) DeleteServiceAccount(sa *v1.ServiceAccount) error {
 	return err
 }
 
-func (c *Client) DeleteClusterRole(cr *rbacv1beta1.ClusterRole) error {
-	err := c.kclient.RbacV1beta1().ClusterRoles().Delete(cr.GetName(), &metav1.DeleteOptions{})
+func (c *Client) DeleteClusterRole(cr *rbacv1.ClusterRole) error {
+	err := c.kclient.RbacV1().ClusterRoles().Delete(cr.GetName(), &metav1.DeleteOptions{})
 	if apierrors.IsNotFound(err) {
 		return nil
 	}
@@ -406,8 +429,8 @@ func (c *Client) DeleteClusterRole(cr *rbacv1beta1.ClusterRole) error {
 	return err
 }
 
-func (c *Client) DeleteClusterRoleBinding(crb *rbacv1beta1.ClusterRoleBinding) error {
-	err := c.kclient.RbacV1beta1().ClusterRoleBindings().Delete(crb.GetName(), &metav1.DeleteOptions{})
+func (c *Client) DeleteClusterRoleBinding(crb *rbacv1.ClusterRoleBinding) error {
+	err := c.kclient.RbacV1().ClusterRoleBindings().Delete(crb.GetName(), &metav1.DeleteOptions{})
 	if apierrors.IsNotFound(err) {
 		return nil
 	}
@@ -733,15 +756,20 @@ func (c *Client) DeleteIfExists(nsName string) error {
 	return errors.Wrap(err, "deleting ConfigMap object failed")
 }
 
-func (c *Client) CreateIfNotExistConfigMap(cm *v1.ConfigMap) error {
+func (c *Client) CreateIfNotExistConfigMap(cm *v1.ConfigMap) (*v1.ConfigMap, error) {
 	cClient := c.kclient.CoreV1().ConfigMaps(cm.GetNamespace())
-	_, err := cClient.Get(cm.GetName(), metav1.GetOptions{})
+	res, err := cClient.Get(cm.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
-		_, err := cClient.Create(cm)
-		return errors.Wrap(err, "creating ConfigMap object failed")
+		res, err := cClient.Create(cm)
+		if err != nil {
+			return nil, errors.Wrap(err, "creating ConfigMap object failed")
+		}
+		return res, nil
 	}
-
-	return errors.Wrap(err, "retrieving ConfigMap object failed")
+	if err != nil {
+		return nil, errors.Wrap(err, "retrieving ConfigMap object failed")
+	}
+	return res, nil
 }
 
 func (c *Client) CreateOrUpdateService(svc *v1.Service) error {
@@ -784,8 +812,8 @@ func (c *Client) CreateOrUpdateEndpoints(endpoints *v1.Endpoints) error {
 	return errors.Wrap(err, "updating Endpoints object failed")
 }
 
-func (c *Client) CreateOrUpdateRoleBinding(rb *rbacv1beta1.RoleBinding) error {
-	rbClient := c.kclient.RbacV1beta1().RoleBindings(rb.GetNamespace())
+func (c *Client) CreateOrUpdateRoleBinding(rb *rbacv1.RoleBinding) error {
+	rbClient := c.kclient.RbacV1().RoleBindings(rb.GetNamespace())
 	r, err := rbClient.Get(rb.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		_, err := rbClient.Create(rb)
@@ -806,8 +834,8 @@ func (c *Client) CreateOrUpdateRoleBinding(rb *rbacv1beta1.RoleBinding) error {
 	return errors.Wrap(err, "updating RoleBinding object failed")
 }
 
-func (c *Client) CreateOrUpdateRole(r *rbacv1beta1.Role) error {
-	rClient := c.kclient.RbacV1beta1().Roles(r.GetNamespace())
+func (c *Client) CreateOrUpdateRole(r *rbacv1.Role) error {
+	rClient := c.kclient.RbacV1().Roles(r.GetNamespace())
 	_, err := rClient.Get(r.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		_, err := rClient.Create(r)
@@ -821,8 +849,8 @@ func (c *Client) CreateOrUpdateRole(r *rbacv1beta1.Role) error {
 	return errors.Wrap(err, "updating Role object failed")
 }
 
-func (c *Client) CreateOrUpdateClusterRole(cr *rbacv1beta1.ClusterRole) error {
-	crClient := c.kclient.RbacV1beta1().ClusterRoles()
+func (c *Client) CreateOrUpdateClusterRole(cr *rbacv1.ClusterRole) error {
+	crClient := c.kclient.RbacV1().ClusterRoles()
 	_, err := crClient.Get(cr.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		_, err := crClient.Create(cr)
@@ -836,8 +864,8 @@ func (c *Client) CreateOrUpdateClusterRole(cr *rbacv1beta1.ClusterRole) error {
 	return errors.Wrap(err, "updating ClusterRole object failed")
 }
 
-func (c *Client) CreateOrUpdateClusterRoleBinding(crb *rbacv1beta1.ClusterRoleBinding) error {
-	crbClient := c.kclient.RbacV1beta1().ClusterRoleBindings()
+func (c *Client) CreateOrUpdateClusterRoleBinding(crb *rbacv1.ClusterRoleBinding) error {
+	crbClient := c.kclient.RbacV1().ClusterRoleBindings()
 	_, err := crbClient.Get(crb.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		_, err := crbClient.Create(crb)
