@@ -16,6 +16,8 @@ package manifests
 
 import (
 	"bytes"
+
+	// #nosec
 	"crypto/sha1"
 	"encoding/base64"
 	"encoding/json"
@@ -34,7 +36,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1beta2"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/api/extensions/v1beta1"
-	rbacv1beta1 "k8s.io/api/rbac/v1beta1"
+	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/yaml"
 	apiregistrationv1beta1 "k8s.io/kube-aggregator/pkg/apis/apiregistration/v1beta1"
@@ -50,6 +52,7 @@ var (
 	AlertmanagerClusterRole        = "assets/alertmanager/cluster-role.yaml"
 	AlertmanagerRoute              = "assets/alertmanager/route.yaml"
 	AlertmanagerServiceMonitor     = "assets/alertmanager/service-monitor.yaml"
+	AlertmanagerTrustedCABundle    = "assets/alertmanager/trusted-ca-bundle.yaml"
 
 	KubeStateMetricsClusterRoleBinding = "assets/kube-state-metrics/cluster-role-binding.yaml"
 	KubeStateMetricsClusterRole        = "assets/kube-state-metrics/cluster-role.yaml"
@@ -58,6 +61,13 @@ var (
 	KubeStateMetricsService            = "assets/kube-state-metrics/service.yaml"
 	KubeStateMetricsServiceMonitor     = "assets/kube-state-metrics/service-monitor.yaml"
 
+	OpenShiftStateMetricsClusterRoleBinding = "assets/openshift-state-metrics/cluster-role-binding.yaml"
+	OpenShiftStateMetricsClusterRole        = "assets/openshift-state-metrics/cluster-role.yaml"
+	OpenShiftStateMetricsDeployment         = "assets/openshift-state-metrics/deployment.yaml"
+	OpenShiftStateMetricsServiceAccount     = "assets/openshift-state-metrics/service-account.yaml"
+	OpenShiftStateMetricsService            = "assets/openshift-state-metrics/service.yaml"
+	OpenShiftStateMetricsServiceMonitor     = "assets/openshift-state-metrics/service-monitor.yaml"
+
 	NodeExporterDaemonSet                  = "assets/node-exporter/daemonset.yaml"
 	NodeExporterService                    = "assets/node-exporter/service.yaml"
 	NodeExporterServiceAccount             = "assets/node-exporter/service-account.yaml"
@@ -66,30 +76,25 @@ var (
 	NodeExporterSecurityContextConstraints = "assets/node-exporter/security-context-constraints.yaml"
 	NodeExporterServiceMonitor             = "assets/node-exporter/service-monitor.yaml"
 
-	PrometheusK8sClusterRoleBinding                   = "assets/prometheus-k8s/cluster-role-binding.yaml"
-	PrometheusK8sRoleBindingConfig                    = "assets/prometheus-k8s/role-binding-config.yaml"
-	PrometheusK8sRoleBindingList                      = "assets/prometheus-k8s/role-binding-specific-namespaces.yaml"
-	PrometheusK8sClusterRole                          = "assets/prometheus-k8s/cluster-role.yaml"
-	PrometheusK8sRoleConfig                           = "assets/prometheus-k8s/role-config.yaml"
-	PrometheusK8sRoleList                             = "assets/prometheus-k8s/role-specific-namespaces.yaml"
-	PrometheusK8sRules                                = "assets/prometheus-k8s/rules.yaml"
-	PrometheusK8sServiceAccount                       = "assets/prometheus-k8s/service-account.yaml"
-	PrometheusK8s                                     = "assets/prometheus-k8s/prometheus.yaml"
-	PrometheusK8sKubeletServiceMonitor                = "assets/prometheus-k8s/service-monitor-kubelet.yaml"
-	PrometheusK8sApiserverServiceMonitor              = "assets/prometheus-k8s/service-monitor-apiserver.yaml"
-	PrometheusK8sPrometheusServiceMonitor             = "assets/prometheus-k8s/service-monitor.yaml"
-	PrometheusK8sKubeControllerManagerServiceMonitor  = "assets/prometheus-k8s/service-monitor-kube-controller-manager.yaml"
-	PrometheusK8sKubeSchedulerServiceMonitor          = "assets/prometheus-k8s/service-monitor-kube-scheduler.yaml"
-	PrometheusK8sServiceMonitorClusterVersionOperator = "assets/prometheus-k8s/service-monitor-cluster-version-operator.yaml"
-	PrometheusK8sServiceMonitorOpenShiftApiserver     = "assets/prometheus-k8s/service-monitor-open-shift-apiserver.yaml"
-	PrometheusK8sService                              = "assets/prometheus-k8s/service.yaml"
-	PrometheusK8sProxySecret                          = "assets/prometheus-k8s/proxy-secret.yaml"
-	PrometheusRBACProxySecret                         = "assets/prometheus-k8s/kube-rbac-proxy-secret.yaml"
-	PrometheusK8sRoute                                = "assets/prometheus-k8s/route.yaml"
-	PrometheusK8sHtpasswd                             = "assets/prometheus-k8s/htpasswd-secret.yaml"
-	PrometheusK8sEtcdServiceMonitor                   = "assets/prometheus-k8s/service-monitor-etcd.yaml"
-	PrometheusK8sServingCertsCABundle                 = "assets/prometheus-k8s/serving-certs-ca-bundle.yaml"
-	PrometheusK8sKubeletServingCABundle               = "assets/prometheus-k8s/kubelet-serving-ca-bundle.yaml"
+	PrometheusK8sClusterRoleBinding       = "assets/prometheus-k8s/cluster-role-binding.yaml"
+	PrometheusK8sRoleBindingConfig        = "assets/prometheus-k8s/role-binding-config.yaml"
+	PrometheusK8sRoleBindingList          = "assets/prometheus-k8s/role-binding-specific-namespaces.yaml"
+	PrometheusK8sClusterRole              = "assets/prometheus-k8s/cluster-role.yaml"
+	PrometheusK8sRoleConfig               = "assets/prometheus-k8s/role-config.yaml"
+	PrometheusK8sRoleList                 = "assets/prometheus-k8s/role-specific-namespaces.yaml"
+	PrometheusK8sRules                    = "assets/prometheus-k8s/rules.yaml"
+	PrometheusK8sServiceAccount           = "assets/prometheus-k8s/service-account.yaml"
+	PrometheusK8s                         = "assets/prometheus-k8s/prometheus.yaml"
+	PrometheusK8sKubeletServiceMonitor    = "assets/prometheus-k8s/service-monitor-kubelet.yaml"
+	PrometheusK8sPrometheusServiceMonitor = "assets/prometheus-k8s/service-monitor.yaml"
+	PrometheusK8sService                  = "assets/prometheus-k8s/service.yaml"
+	PrometheusK8sProxySecret              = "assets/prometheus-k8s/proxy-secret.yaml"
+	PrometheusRBACProxySecret             = "assets/prometheus-k8s/kube-rbac-proxy-secret.yaml"
+	PrometheusK8sRoute                    = "assets/prometheus-k8s/route.yaml"
+	PrometheusK8sHtpasswd                 = "assets/prometheus-k8s/htpasswd-secret.yaml"
+	PrometheusK8sEtcdServiceMonitor       = "assets/prometheus-k8s/service-monitor-etcd.yaml"
+	PrometheusK8sServingCertsCABundle     = "assets/prometheus-k8s/serving-certs-ca-bundle.yaml"
+	PrometheusK8sKubeletServingCABundle   = "assets/prometheus-k8s/kubelet-serving-ca-bundle.yaml"
 
 	PrometheusAdapterAPIService                         = "assets/prometheus-adapter/api-service.yaml"
 	PrometheusAdapterClusterRole                        = "assets/prometheus-adapter/cluster-role.yaml"
@@ -138,6 +143,7 @@ var (
 	TelemeterClientServiceAccount         = "assets/telemeter-client/service-account.yaml"
 	TelemeterClientServiceMonitor         = "assets/telemeter-client/service-monitor.yaml"
 	TelemeterClientServingCertsCABundle   = "assets/telemeter-client/serving-certs-c-a-bundle.yaml"
+	TelemeterTrustedCABundle              = "assets/telemeter-client/trusted-ca-bundle.yaml"
 )
 
 var (
@@ -239,7 +245,7 @@ func (f *Factory) AlertmanagerServiceAccount() (*v1.ServiceAccount, error) {
 	return s, nil
 }
 
-func (f *Factory) AlertmanagerClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) AlertmanagerClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(AlertmanagerClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -250,7 +256,7 @@ func (f *Factory) AlertmanagerClusterRoleBinding() (*rbacv1beta1.ClusterRoleBind
 	return crb, nil
 }
 
-func (f *Factory) AlertmanagerClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) AlertmanagerClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(AlertmanagerClusterRole))
 }
 
@@ -266,7 +272,16 @@ func (f *Factory) AlertmanagerServiceMonitor() (*monv1.ServiceMonitor, error) {
 	return sm, nil
 }
 
-func (f *Factory) AlertmanagerMain(host string) (*monv1.Alertmanager, error) {
+func (f *Factory) AlertmanagerTrustedCABundle() (*v1.ConfigMap, error) {
+	cm, err := f.NewConfigMap(MustAssetReader(AlertmanagerTrustedCABundle))
+	if err != nil {
+		return nil, err
+	}
+
+	return cm, nil
+}
+
+func (f *Factory) AlertmanagerMain(host string, trustedCABundleCM *v1.ConfigMap) (*monv1.Alertmanager, error) {
 	a, err := f.NewAlertmanager(MustAssetReader(AlertmanagerMain))
 	if err != nil {
 		return nil, err
@@ -290,21 +305,34 @@ func (f *Factory) AlertmanagerMain(host string) (*monv1.Alertmanager, error) {
 		a.Spec.NodeSelector = f.config.AlertmanagerMainConfig.NodeSelector
 	}
 
-	a.Spec.Containers[0].Image = f.config.Images.OauthProxy
+	if len(f.config.AlertmanagerMainConfig.Tolerations) > 0 {
+		a.Spec.Tolerations = f.config.AlertmanagerMainConfig.Tolerations
+	}
 
-	for c := range a.Spec.Containers {
-		for e := range a.Spec.Containers[c].Env {
-			switch a.Spec.Containers[c].Env[e].Name {
-			case "HTTP_PROXY":
-				a.Spec.Containers[c].Env[e].Value = f.config.HTTPConfig.HTTPProxy
-			case "HTTPS_PROXY":
-				a.Spec.Containers[c].Env[e].Value = f.config.HTTPConfig.HTTPSProxy
-			case "NO_PROXY":
-				a.Spec.Containers[c].Env[e].Value = f.config.HTTPConfig.NoProxy
+	a.Spec.Containers[0].Image = f.config.Images.OauthProxy
+	setEnv := func(name, value string) {
+		for i := range a.Spec.Containers[0].Env {
+			if a.Spec.Containers[0].Env[i].Name == name {
+				a.Spec.Containers[0].Env[i].Value = value
+				break
 			}
 		}
 	}
+	if f.config.HTTPConfig.HTTPProxy != "" {
+		setEnv("HTTP_PROXY", f.config.HTTPConfig.HTTPProxy)
+	}
+	if f.config.HTTPConfig.HTTPSProxy != "" {
+		setEnv("HTTPS_PROXY", f.config.HTTPConfig.HTTPSProxy)
+	}
+	if f.config.HTTPConfig.NoProxy != "" {
+		setEnv("NO_PROXY", f.config.HTTPConfig.NoProxy)
+	}
 
+	if trustedCABundleCM != nil {
+		volumeName := "alertmanager-trusted-ca-bundle"
+		a.Spec.VolumeMounts = append(a.Spec.VolumeMounts, trustedCABundleVolumeMount(volumeName, "/etc/pki/alertmanager-ca-bundle/"))
+		a.Spec.Volumes = append(a.Spec.Volumes, trustedCABundleVolume(trustedCABundleCM.Name, volumeName))
+	}
 	a.Namespace = f.namespace
 
 	return a, nil
@@ -324,7 +352,7 @@ func (f *Factory) AlertmanagerRoute() (*routev1.Route, error) {
 	return r, nil
 }
 
-func (f *Factory) KubeStateMetricsClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) KubeStateMetricsClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(KubeStateMetricsClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -335,7 +363,7 @@ func (f *Factory) KubeStateMetricsClusterRoleBinding() (*rbacv1beta1.ClusterRole
 	return crb, nil
 }
 
-func (f *Factory) KubeStateMetricsClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) KubeStateMetricsClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(KubeStateMetricsClusterRole))
 }
 
@@ -366,6 +394,9 @@ func (f *Factory) KubeStateMetricsDeployment() (*appsv1.Deployment, error) {
 		d.Spec.Template.Spec.NodeSelector = f.config.KubeStateMetricsConfig.NodeSelector
 	}
 
+	if len(f.config.KubeStateMetricsConfig.Tolerations) > 0 {
+		d.Spec.Template.Spec.Tolerations = f.config.KubeStateMetricsConfig.Tolerations
+	}
 	d.Namespace = f.namespace
 
 	return d, nil
@@ -393,6 +424,78 @@ func (f *Factory) KubeStateMetricsService() (*v1.Service, error) {
 	return s, nil
 }
 
+func (f *Factory) OpenShiftStateMetricsClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
+	crb, err := f.NewClusterRoleBinding(MustAssetReader(OpenShiftStateMetricsClusterRoleBinding))
+	if err != nil {
+		return nil, err
+	}
+
+	crb.Subjects[0].Namespace = f.namespace
+
+	return crb, nil
+}
+
+func (f *Factory) OpenShiftStateMetricsClusterRole() (*rbacv1.ClusterRole, error) {
+	return f.NewClusterRole(MustAssetReader(OpenShiftStateMetricsClusterRole))
+}
+
+func (f *Factory) OpenShiftStateMetricsServiceMonitor() (*monv1.ServiceMonitor, error) {
+	sm, err := f.NewServiceMonitor(MustAssetReader(OpenShiftStateMetricsServiceMonitor))
+	if err != nil {
+		return nil, err
+	}
+
+	sm.Spec.Endpoints[0].TLSConfig.ServerName = fmt.Sprintf("openshift-state-metrics.%s.svc", f.namespace)
+	sm.Spec.Endpoints[1].TLSConfig.ServerName = fmt.Sprintf("openshift-state-metrics.%s.svc", f.namespace)
+	sm.Namespace = f.namespace
+
+	return sm, nil
+}
+
+func (f *Factory) OpenShiftStateMetricsDeployment() (*appsv1.Deployment, error) {
+	d, err := f.NewDeployment(MustAssetReader(OpenShiftStateMetricsDeployment))
+	if err != nil {
+		return nil, err
+	}
+
+	d.Spec.Template.Spec.Containers[0].Image = f.config.Images.KubeRbacProxy
+	d.Spec.Template.Spec.Containers[1].Image = f.config.Images.KubeRbacProxy
+	d.Spec.Template.Spec.Containers[2].Image = f.config.Images.OpenShiftStateMetrics
+
+	if f.config.OpenShiftMetricsConfig.NodeSelector != nil {
+		d.Spec.Template.Spec.NodeSelector = f.config.OpenShiftMetricsConfig.NodeSelector
+	}
+
+	if len(f.config.OpenShiftMetricsConfig.Tolerations) > 0 {
+		d.Spec.Template.Spec.Tolerations = f.config.OpenShiftMetricsConfig.Tolerations
+	}
+	d.Namespace = f.namespace
+
+	return d, nil
+}
+
+func (f *Factory) OpenShiftStateMetricsServiceAccount() (*v1.ServiceAccount, error) {
+	s, err := f.NewServiceAccount(MustAssetReader(OpenShiftStateMetricsServiceAccount))
+	if err != nil {
+		return nil, err
+	}
+
+	s.Namespace = f.namespace
+
+	return s, nil
+}
+
+func (f *Factory) OpenShiftStateMetricsService() (*v1.Service, error) {
+	s, err := f.NewService(MustAssetReader(OpenShiftStateMetricsService))
+	if err != nil {
+		return nil, err
+	}
+
+	s.Namespace = f.namespace
+
+	return s, nil
+}
+
 func (f *Factory) NodeExporterServiceMonitor() (*monv1.ServiceMonitor, error) {
 	sm, err := f.NewServiceMonitor(MustAssetReader(NodeExporterServiceMonitor))
 	if err != nil {
@@ -450,7 +553,7 @@ func (f *Factory) NodeExporterServiceAccount() (*v1.ServiceAccount, error) {
 	return s, nil
 }
 
-func (f *Factory) NodeExporterClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) NodeExporterClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(NodeExporterClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -461,11 +564,11 @@ func (f *Factory) NodeExporterClusterRoleBinding() (*rbacv1beta1.ClusterRoleBind
 	return crb, nil
 }
 
-func (f *Factory) NodeExporterClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) NodeExporterClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(NodeExporterClusterRole))
 }
 
-func (f *Factory) PrometheusK8sClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) PrometheusK8sClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(PrometheusK8sClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -476,11 +579,11 @@ func (f *Factory) PrometheusK8sClusterRoleBinding() (*rbacv1beta1.ClusterRoleBin
 	return crb, nil
 }
 
-func (f *Factory) PrometheusK8sClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) PrometheusK8sClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(PrometheusK8sClusterRole))
 }
 
-func (f *Factory) PrometheusK8sRoleConfig() (*rbacv1beta1.Role, error) {
+func (f *Factory) PrometheusK8sRoleConfig() (*rbacv1.Role, error) {
 	r, err := f.NewRole(MustAssetReader(PrometheusK8sRoleConfig))
 	if err != nil {
 		return nil, err
@@ -491,7 +594,7 @@ func (f *Factory) PrometheusK8sRoleConfig() (*rbacv1beta1.Role, error) {
 	return r, nil
 }
 
-func (f *Factory) PrometheusK8sRoleBindingList() (*rbacv1beta1.RoleBindingList, error) {
+func (f *Factory) PrometheusK8sRoleBindingList() (*rbacv1.RoleBindingList, error) {
 	rbl, err := f.NewRoleBindingList(MustAssetReader(PrometheusK8sRoleBindingList))
 	if err != nil {
 		return nil, err
@@ -504,7 +607,7 @@ func (f *Factory) PrometheusK8sRoleBindingList() (*rbacv1beta1.RoleBindingList,
 	return rbl, nil
 }
 
-func (f *Factory) PrometheusK8sRoleBindingConfig() (*rbacv1beta1.RoleBinding, error) {
+func (f *Factory) PrometheusK8sRoleBindingConfig() (*rbacv1.RoleBinding, error) {
 	rb, err := f.NewRoleBinding(MustAssetReader(PrometheusK8sRoleBindingConfig))
 	if err != nil {
 		return nil, err
@@ -515,7 +618,7 @@ func (f *Factory) PrometheusK8sRoleBindingConfig() (*rbacv1beta1.RoleBinding, er
 	return rb, nil
 }
 
-func (f *Factory) PrometheusK8sRoleList() (*rbacv1beta1.RoleList, error) {
+func (f *Factory) PrometheusK8sRoleList() (*rbacv1.RoleList, error) {
 	rl, err := f.NewRoleList(MustAssetReader(PrometheusK8sRoleList))
 	if err != nil {
 		return nil, err
@@ -582,6 +685,8 @@ func (f *Factory) PrometheusK8sHtpasswdSecret(password string) (*v1.Secret, erro
 		return nil, err
 	}
 
+	// #nosec
+	// TODO: Replace this with a safer algorithm
 	h := sha1.New()
 	h.Write([]byte(password))
 	s.Data["auth"] = []byte("internal:{SHA}" + base64.StdEncoding.EncodeToString(h.Sum(nil)))
@@ -720,6 +825,10 @@ func (f *Factory) PrometheusK8s(host string) (*monv1.Prometheus, error) {
 		p.Spec.NodeSelector = f.config.PrometheusK8sConfig.NodeSelector
 	}
 
+	if len(f.config.PrometheusK8sConfig.Tolerations) > 0 {
+		p.Spec.Tolerations = f.config.PrometheusK8sConfig.Tolerations
+	}
+
 	if f.config.PrometheusK8sConfig.ExternalLabels != nil {
 		p.Spec.ExternalLabels = f.config.PrometheusK8sConfig.ExternalLabels
 	}
@@ -730,6 +839,10 @@ func (f *Factory) PrometheusK8s(host string) (*monv1.Prometheus, error) {
 		}
 	}
 
+	if len(f.config.PrometheusK8sConfig.RemoteWrite) > 0 {
+		p.Spec.RemoteWrite = f.config.PrometheusK8sConfig.RemoteWrite
+	}
+
 	if !f.config.EtcdConfig.IsEnabled() {
 		secrets := []string{}
 		for _, s := range p.Spec.Secrets {
@@ -748,6 +861,24 @@ func (f *Factory) PrometheusK8s(host string) (*monv1.Prometheus, error) {
 	p.Spec.Alerting.Alertmanagers[0].TLSConfig.ServerName = fmt.Sprintf("alertmanager-main.%s.svc", f.namespace)
 	p.Namespace = f.namespace
 
+	setEnv := func(name, value string) {
+		for i := range p.Spec.Containers[0].Env {
+			if p.Spec.Containers[0].Env[i].Name == name {
+				p.Spec.Containers[0].Env[i].Value = value
+				break
+			}
+		}
+	}
+	if f.config.HTTPConfig.HTTPProxy != "" {
+		setEnv("HTTP_PROXY", f.config.HTTPConfig.HTTPProxy)
+	}
+	if f.config.HTTPConfig.HTTPSProxy != "" {
+		setEnv("HTTPS_PROXY", f.config.HTTPConfig.HTTPSProxy)
+	}
+	if f.config.HTTPConfig.NoProxy != "" {
+		setEnv("NO_PROXY", f.config.HTTPConfig.NoProxy)
+	}
+
 	return p, nil
 }
 
@@ -762,17 +893,6 @@ func (f *Factory) PrometheusK8sKubeletServiceMonitor() (*monv1.ServiceMonitor, e
 	return s, nil
 }
 
-func (f *Factory) PrometheusK8sApiserverServiceMonitor() (*monv1.ServiceMonitor, error) {
-	s, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sApiserverServiceMonitor))
-	if err != nil {
-		return nil, err
-	}
-
-	s.Namespace = f.namespace
-
-	return s, nil
-}
-
 func (f *Factory) PrometheusK8sPrometheusServiceMonitor() (*monv1.ServiceMonitor, error) {
 	sm, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sPrometheusServiceMonitor))
 	if err != nil {
@@ -785,63 +905,19 @@ func (f *Factory) PrometheusK8sPrometheusServiceMonitor() (*monv1.ServiceMonitor
 	return sm, nil
 }
 
-func (f *Factory) PrometheusK8sKubeSchedulerServiceMonitor() (*monv1.ServiceMonitor, error) {
-	s, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sKubeSchedulerServiceMonitor))
-	if err != nil {
-		return nil, err
-	}
-
-	s.Namespace = f.namespace
-
-	return s, nil
-}
-
-func (f *Factory) PrometheusK8sKubeControllerManagerServiceMonitor() (*monv1.ServiceMonitor, error) {
-	s, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sKubeControllerManagerServiceMonitor))
-	if err != nil {
-		return nil, err
-	}
-
-	s.Namespace = f.namespace
-
-	return s, nil
-}
-
-func (f *Factory) PrometheusK8sServiceMonitorClusterVersionOperator() (*monv1.ServiceMonitor, error) {
-	s, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sServiceMonitorClusterVersionOperator))
-	if err != nil {
-		return nil, err
-	}
-
-	s.Namespace = f.namespace
-
-	return s, nil
-}
-
-func (f *Factory) PrometheusK8sServiceMonitorOpenShiftApiserver() (*monv1.ServiceMonitor, error) {
-	s, err := f.NewServiceMonitor(MustAssetReader(PrometheusK8sServiceMonitorOpenShiftApiserver))
-	if err != nil {
-		return nil, err
-	}
-
-	s.Namespace = f.namespace
-
-	return s, nil
-}
-
-func (f *Factory) PrometheusAdapterClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) PrometheusAdapterClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(PrometheusAdapterClusterRole))
 }
 
-func (f *Factory) PrometheusAdapterClusterRoleServerResources() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) PrometheusAdapterClusterRoleServerResources() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(PrometheusAdapterClusterRoleServerResources))
 }
 
-func (f *Factory) PrometheusAdapterClusterRoleAggregatedMetricsReader() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) PrometheusAdapterClusterRoleAggregatedMetricsReader() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(PrometheusAdapterClusterRoleAggregatedMetricsReader))
 }
 
-func (f *Factory) PrometheusAdapterClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) PrometheusAdapterClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(PrometheusAdapterClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -852,7 +928,7 @@ func (f *Factory) PrometheusAdapterClusterRoleBinding() (*rbacv1beta1.ClusterRol
 	return crb, nil
 }
 
-func (f *Factory) PrometheusAdapterClusterRoleBindingDelegator() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) PrometheusAdapterClusterRoleBindingDelegator() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(PrometheusAdapterClusterRoleBindingDelegator))
 	if err != nil {
 		return nil, err
@@ -863,7 +939,7 @@ func (f *Factory) PrometheusAdapterClusterRoleBindingDelegator() (*rbacv1beta1.C
 	return crb, nil
 }
 
-func (f *Factory) PrometheusAdapterClusterRoleBindingView() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) PrometheusAdapterClusterRoleBindingView() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(PrometheusAdapterClusterRoleBindingView))
 	if err != nil {
 		return nil, err
@@ -874,7 +950,7 @@ func (f *Factory) PrometheusAdapterClusterRoleBindingView() (*rbacv1beta1.Cluste
 	return crb, nil
 }
 
-func (f *Factory) PrometheusAdapterRoleBindingAuthReader() (*rbacv1beta1.RoleBinding, error) {
+func (f *Factory) PrometheusAdapterRoleBindingAuthReader() (*rbacv1.RoleBinding, error) {
 	rb, err := f.NewRoleBinding(MustAssetReader(PrometheusAdapterRoleBindingAuthReader))
 	if err != nil {
 		return nil, err
@@ -930,6 +1006,10 @@ func (f *Factory) PrometheusAdapterDeployment(apiAuthSecretName string, requesth
 	if f.config.K8sPrometheusAdapter != nil && len(f.config.K8sPrometheusAdapter.NodeSelector) > 0 {
 		spec.NodeSelector = f.config.K8sPrometheusAdapter.NodeSelector
 	}
+
+	if f.config.K8sPrometheusAdapter != nil && len(f.config.K8sPrometheusAdapter.Tolerations) > 0 {
+		spec.Tolerations = f.config.K8sPrometheusAdapter.Tolerations
+	}
 	dep.Namespace = f.namespace
 
 	r := newErrMapReader(requestheader)
@@ -1052,7 +1132,7 @@ func (f *Factory) PrometheusOperatorServiceMonitor() (*monv1.ServiceMonitor, err
 	return sm, nil
 }
 
-func (f *Factory) PrometheusOperatorClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) PrometheusOperatorClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(PrometheusOperatorClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -1063,7 +1143,7 @@ func (f *Factory) PrometheusOperatorClusterRoleBinding() (*rbacv1beta1.ClusterRo
 	return crb, nil
 }
 
-func (f *Factory) PrometheusOperatorClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) PrometheusOperatorClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(PrometheusOperatorClusterRole))
 }
 
@@ -1088,6 +1168,10 @@ func (f *Factory) PrometheusOperatorDeployment(namespaces []string) (*appsv1.Dep
 		d.Spec.Template.Spec.NodeSelector = f.config.PrometheusOperatorConfig.NodeSelector
 	}
 
+	if len(f.config.PrometheusOperatorConfig.Tolerations) > 0 {
+		d.Spec.Template.Spec.Tolerations = f.config.PrometheusOperatorConfig.Tolerations
+	}
+
 	d.Spec.Template.Spec.Containers[0].Image = f.config.Images.PrometheusOperator
 
 	args := d.Spec.Template.Spec.Containers[0].Args
@@ -1132,7 +1216,7 @@ func (f *Factory) PrometheusK8sService() (*v1.Service, error) {
 	return s, nil
 }
 
-func (f *Factory) GrafanaClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) GrafanaClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(GrafanaClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -1143,7 +1227,7 @@ func (f *Factory) GrafanaClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding,
 	return crb, nil
 }
 
-func (f *Factory) GrafanaClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) GrafanaClusterRole() (*rbacv1.ClusterRole, error) {
 	return f.NewClusterRole(MustAssetReader(GrafanaClusterRole))
 }
 
@@ -1188,7 +1272,7 @@ func (f *Factory) GrafanaDatasources() (*v1.Secret, error) {
 	}
 
 	d := &GrafanaDatasources{}
-	err = json.Unmarshal(s.Data["prometheus.yaml"], d)
+	err = json.Unmarshal(s.Data["datasources.yaml"], d)
 	if err != nil {
 		return nil, err
 	}
@@ -1269,10 +1353,32 @@ func (f *Factory) GrafanaDeployment() (*appsv1.Deployment, error) {
 
 	d.Spec.Template.Spec.Containers[1].Image = f.config.Images.OauthProxy
 
+	setEnv := func(name, value string) {
+		for i := range d.Spec.Template.Spec.Containers[1].Env {
+			if d.Spec.Template.Spec.Containers[1].Env[i].Name == name {
+				d.Spec.Template.Spec.Containers[1].Env[i].Value = value
+				break
+			}
+		}
+	}
+	if f.config.HTTPConfig.HTTPProxy != "" {
+		setEnv("HTTP_PROXY", f.config.HTTPConfig.HTTPProxy)
+	}
+	if f.config.HTTPConfig.HTTPSProxy != "" {
+		setEnv("HTTPS_PROXY", f.config.HTTPConfig.HTTPSProxy)
+	}
+	if f.config.HTTPConfig.NoProxy != "" {
+		setEnv("NO_PROXY", f.config.HTTPConfig.NoProxy)
+	}
+
 	if f.config.GrafanaConfig.NodeSelector != nil {
 		d.Spec.Template.Spec.NodeSelector = f.config.GrafanaConfig.NodeSelector
 	}
 
+	if len(f.config.GrafanaConfig.Tolerations) > 0 {
+		d.Spec.Template.Spec.Tolerations = f.config.GrafanaConfig.Tolerations
+	}
+
 	d.Namespace = f.namespace
 
 	return d, nil
@@ -1342,7 +1448,7 @@ func (f *Factory) GrafanaServiceMonitor() (*monv1.ServiceMonitor, error) {
 	return s, nil
 }
 
-func (f *Factory) ClusterMonitoringClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) ClusterMonitoringClusterRole() (*rbacv1.ClusterRole, error) {
 	cr, err := f.NewClusterRole(MustAssetReader(ClusterMonitoringClusterRole))
 	if err != nil {
 		return nil, err
@@ -1461,7 +1567,7 @@ func (f *Factory) NewSecret(manifest io.Reader) (*v1.Secret, error) {
 	return s, nil
 }
 
-func (f *Factory) NewRoleBinding(manifest io.Reader) (*rbacv1beta1.RoleBinding, error) {
+func (f *Factory) NewRoleBinding(manifest io.Reader) (*rbacv1.RoleBinding, error) {
 	rb, err := NewRoleBinding(manifest)
 	if err != nil {
 		return nil, err
@@ -1474,7 +1580,7 @@ func (f *Factory) NewRoleBinding(manifest io.Reader) (*rbacv1beta1.RoleBinding,
 	return rb, nil
 }
 
-func (f *Factory) NewRoleList(manifest io.Reader) (*rbacv1beta1.RoleList, error) {
+func (f *Factory) NewRoleList(manifest io.Reader) (*rbacv1.RoleList, error) {
 	rl, err := NewRoleList(manifest)
 	if err != nil {
 		return nil, err
@@ -1489,7 +1595,7 @@ func (f *Factory) NewRoleList(manifest io.Reader) (*rbacv1beta1.RoleList, error)
 	return rl, nil
 }
 
-func (f *Factory) NewRoleBindingList(manifest io.Reader) (*rbacv1beta1.RoleBindingList, error) {
+func (f *Factory) NewRoleBindingList(manifest io.Reader) (*rbacv1.RoleBindingList, error) {
 	rbl, err := NewRoleBindingList(manifest)
 	if err != nil {
 		return nil, err
@@ -1504,7 +1610,7 @@ func (f *Factory) NewRoleBindingList(manifest io.Reader) (*rbacv1beta1.RoleBindi
 	return rbl, nil
 }
 
-func (f *Factory) NewRole(manifest io.Reader) (*rbacv1beta1.Role, error) {
+func (f *Factory) NewRole(manifest io.Reader) (*rbacv1.Role, error) {
 	r, err := NewRole(manifest)
 	if err != nil {
 		return nil, err
@@ -1644,14 +1750,23 @@ func (f *Factory) NewSecurityContextConstraints(manifest io.Reader) (*securityv1
 	return NewSecurityContextConstraints(manifest)
 }
 
-func (f *Factory) NewClusterRoleBinding(manifest io.Reader) (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) NewClusterRoleBinding(manifest io.Reader) (*rbacv1.ClusterRoleBinding, error) {
 	return NewClusterRoleBinding(manifest)
 }
 
-func (f *Factory) NewClusterRole(manifest io.Reader) (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) NewClusterRole(manifest io.Reader) (*rbacv1.ClusterRole, error) {
 	return NewClusterRole(manifest)
 }
 
+func (f *Factory) TelemeterTrustedCABundle() (*v1.ConfigMap, error) {
+	cm, err := f.NewConfigMap(MustAssetReader(TelemeterTrustedCABundle))
+	if err != nil {
+		return nil, err
+	}
+
+	return cm, nil
+}
+
 // TelemeterClientServingCertsCABundle generates a new servinc certs CA bundle ConfigMap for TelemeterClient.
 func (f *Factory) TelemeterClientServingCertsCABundle() (*v1.ConfigMap, error) {
 	c, err := f.NewConfigMap(MustAssetReader(TelemeterClientServingCertsCABundle))
@@ -1665,7 +1780,7 @@ func (f *Factory) TelemeterClientServingCertsCABundle() (*v1.ConfigMap, error) {
 }
 
 // TelemeterClientClusterRole generates a new ClusterRole for Telemeter client.
-func (f *Factory) TelemeterClientClusterRole() (*rbacv1beta1.ClusterRole, error) {
+func (f *Factory) TelemeterClientClusterRole() (*rbacv1.ClusterRole, error) {
 	cr, err := f.NewClusterRole(MustAssetReader(TelemeterClientClusterRole))
 	if err != nil {
 		return nil, err
@@ -1675,7 +1790,7 @@ func (f *Factory) TelemeterClientClusterRole() (*rbacv1beta1.ClusterRole, error)
 }
 
 // TelemeterClientClusterRoleBinding generates a new ClusterRoleBinding for Telemeter client.
-func (f *Factory) TelemeterClientClusterRoleBinding() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) TelemeterClientClusterRoleBinding() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(TelemeterClientClusterRoleBinding))
 	if err != nil {
 		return nil, err
@@ -1686,7 +1801,7 @@ func (f *Factory) TelemeterClientClusterRoleBinding() (*rbacv1beta1.ClusterRoleB
 
 // TelemeterClientClusterRoleBindingView generates a new ClusterRoleBinding for Telemeter client
 // for the cluster monitoring view ClusterRole.
-func (f *Factory) TelemeterClientClusterRoleBindingView() (*rbacv1beta1.ClusterRoleBinding, error) {
+func (f *Factory) TelemeterClientClusterRoleBindingView() (*rbacv1.ClusterRoleBinding, error) {
 	crb, err := f.NewClusterRoleBinding(MustAssetReader(TelemeterClientClusterRoleBindingView))
 	if err != nil {
 		return nil, err
@@ -1709,7 +1824,9 @@ func (f *Factory) TelemeterClientServiceMonitor() (*monv1.ServiceMonitor, error)
 }
 
 // TelemeterClientDeployment generates a new Deployment for Telemeter client.
-func (f *Factory) TelemeterClientDeployment() (*appsv1.Deployment, error) {
+// If the passed ConfigMap is not empty it mounts the Trusted CA Bundle as a VolumeMount to
+// /etc/pki/ca-trust/extracted/pem/ location.
+func (f *Factory) TelemeterClientDeployment(proxyCABundleCM *v1.ConfigMap) (*appsv1.Deployment, error) {
 	d, err := f.NewDeployment(MustAssetReader(TelemeterClientDeployment))
 	if err != nil {
 		return nil, err
@@ -1730,14 +1847,37 @@ func (f *Factory) TelemeterClientDeployment() (*appsv1.Deployment, error) {
 		setEnv("TO", f.config.TelemeterClientConfig.TelemeterServerURL)
 	}
 
+	if f.config.HTTPConfig.HTTPProxy != "" {
+		setEnv("HTTP_PROXY", f.config.HTTPConfig.HTTPProxy)
+	}
+	if f.config.HTTPConfig.HTTPSProxy != "" {
+		setEnv("HTTPS_PROXY", f.config.HTTPConfig.HTTPSProxy)
+	}
+	if f.config.HTTPConfig.NoProxy != "" {
+		setEnv("NO_PROXY", f.config.HTTPConfig.NoProxy)
+	}
+
 	d.Spec.Template.Spec.Containers[0].Image = f.config.Images.TelemeterClient
 	d.Spec.Template.Spec.Containers[1].Image = f.config.Images.ConfigmapReloader
 	d.Spec.Template.Spec.Containers[2].Image = f.config.Images.KubeRbacProxy
+
 	if len(f.config.TelemeterClientConfig.NodeSelector) > 0 {
 		d.Spec.Template.Spec.NodeSelector = f.config.TelemeterClientConfig.NodeSelector
 	}
+	if len(f.config.TelemeterClientConfig.Tolerations) > 0 {
+		d.Spec.Template.Spec.Tolerations = f.config.TelemeterClientConfig.Tolerations
+	}
 	d.Namespace = f.namespace
-
+	if proxyCABundleCM != nil {
+		volumeName := "telemeter-trusted-ca-bundle"
+		d.Spec.Template.Spec.Containers[0].VolumeMounts = append(d.Spec.Template.Spec.Containers[0].VolumeMounts, trustedCABundleVolumeMount(volumeName, "/etc/pki/ca-trust/extracted/pem/"))
+		volume := trustedCABundleVolume(proxyCABundleCM.Name, volumeName)
+		volume.VolumeSource.ConfigMap.Items = append(volume.VolumeSource.ConfigMap.Items, v1.KeyToPath{
+			Key:  "ca-bundle.crt",
+			Path: "tls-ca-bundle.pem",
+		})
+		d.Spec.Template.Spec.Volumes = append(d.Spec.Template.Spec.Volumes, volume)
+	}
 	return d, nil
 }
 
@@ -1836,8 +1976,8 @@ func NewSecret(manifest io.Reader) (*v1.Secret, error) {
 	return &s, nil
 }
 
-func NewClusterRoleBinding(manifest io.Reader) (*rbacv1beta1.ClusterRoleBinding, error) {
-	crb := rbacv1beta1.ClusterRoleBinding{}
+func NewClusterRoleBinding(manifest io.Reader) (*rbacv1.ClusterRoleBinding, error) {
+	crb := rbacv1.ClusterRoleBinding{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&crb)
 	if err != nil {
 		return nil, err
@@ -1846,8 +1986,8 @@ func NewClusterRoleBinding(manifest io.Reader) (*rbacv1beta1.ClusterRoleBinding,
 	return &crb, nil
 }
 
-func NewClusterRole(manifest io.Reader) (*rbacv1beta1.ClusterRole, error) {
-	cr := rbacv1beta1.ClusterRole{}
+func NewClusterRole(manifest io.Reader) (*rbacv1.ClusterRole, error) {
+	cr := rbacv1.ClusterRole{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&cr)
 	if err != nil {
 		return nil, err
@@ -1856,8 +1996,8 @@ func NewClusterRole(manifest io.Reader) (*rbacv1beta1.ClusterRole, error) {
 	return &cr, nil
 }
 
-func NewRoleBinding(manifest io.Reader) (*rbacv1beta1.RoleBinding, error) {
-	rb := rbacv1beta1.RoleBinding{}
+func NewRoleBinding(manifest io.Reader) (*rbacv1.RoleBinding, error) {
+	rb := rbacv1.RoleBinding{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&rb)
 	if err != nil {
 		return nil, err
@@ -1866,8 +2006,8 @@ func NewRoleBinding(manifest io.Reader) (*rbacv1beta1.RoleBinding, error) {
 	return &rb, nil
 }
 
-func NewRole(manifest io.Reader) (*rbacv1beta1.Role, error) {
-	r := rbacv1beta1.Role{}
+func NewRole(manifest io.Reader) (*rbacv1.Role, error) {
+	r := rbacv1.Role{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&r)
 	if err != nil {
 		return nil, err
@@ -1876,8 +2016,8 @@ func NewRole(manifest io.Reader) (*rbacv1beta1.Role, error) {
 	return &r, nil
 }
 
-func NewRoleBindingList(manifest io.Reader) (*rbacv1beta1.RoleBindingList, error) {
-	rbl := rbacv1beta1.RoleBindingList{}
+func NewRoleBindingList(manifest io.Reader) (*rbacv1.RoleBindingList, error) {
+	rbl := rbacv1.RoleBindingList{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&rbl)
 	if err != nil {
 		return nil, err
@@ -1886,8 +2026,8 @@ func NewRoleBindingList(manifest io.Reader) (*rbacv1beta1.RoleBindingList, error
 	return &rbl, nil
 }
 
-func NewRoleList(manifest io.Reader) (*rbacv1beta1.RoleList, error) {
-	rl := rbacv1beta1.RoleList{}
+func NewRoleList(manifest io.Reader) (*rbacv1.RoleList, error) {
+	rl := rbacv1.RoleList{}
 	err := yaml.NewYAMLOrJSONDecoder(manifest, 100).Decode(&rl)
 	if err != nil {
 		return nil, err
@@ -2005,3 +2145,63 @@ func NewSecurityContextConstraints(manifest io.Reader) (*securityv1.SecurityCont
 
 	return &s, nil
 }
+
+// HashTrustedCA synthesizes a configmap just by copying "ca-bundle.crt" from the given configmap
+// and naming it by hashing the contents of "ca-bundle.crt".
+// It adds "monitoring.openshift.io/name" and "monitoring.openshift.io/hash" labels.
+// Any other labels from the given configmap are discarded.
+//
+// It returns nil, if the given configmap does not contain the "ca-bundle.crt" the data key
+// or data is empty string.
+func (f *Factory) HashTrustedCA(caBundleCM *v1.ConfigMap, prefix string) *v1.ConfigMap {
+	caBundle, ok := caBundleCM.Data["ca-bundle.crt"]
+	if !ok || caBundle == "" {
+		// We return here instead of erroring out as we need
+		// "ca-bundle.crt" to be there. This can mean that
+		// the CA was not propagated yet. In that case we
+		// will catch this on next sync loop.
+		return nil
+	}
+
+	h := fnv.New64()
+	h.Write([]byte(caBundle))
+	hash := strconv.FormatUint(h.Sum64(), 32)
+
+	return &v1.ConfigMap{
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: "openshift-monitoring",
+			Name:      fmt.Sprintf("%s-trusted-ca-bundle-%s", prefix, hash),
+			Labels: map[string]string{
+				"monitoring.openshift.io/name": prefix,
+				"monitoring.openshift.io/hash": hash,
+			},
+		},
+		Data: map[string]string{
+			"ca-bundle.crt": caBundle,
+		},
+	}
+}
+
+func trustedCABundleVolumeMount(name, path string) v1.VolumeMount {
+	return v1.VolumeMount{
+		Name:      name,
+		ReadOnly:  true,
+		MountPath: path,
+	}
+}
+
+func trustedCABundleVolume(configMapName, volumeName string) v1.Volume {
+	yes := true
+
+	return v1.Volume{
+		Name: volumeName,
+		VolumeSource: v1.VolumeSource{
+			ConfigMap: &v1.ConfigMapVolumeSource{
+				LocalObjectReference: v1.LocalObjectReference{
+					Name: configMapName,
+				},
+				Optional: &yes,
+			},
+		},
+	}
+}
